#
# spec file for package python-FormEncode
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-FormEncode
Version:        1.3.0
Release:        4.21
Url:            http://formencode.org
Summary:        HTML form validation, generation, and conversion package
License:        Python-2.0
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/F/FormEncode/FormEncode-%{version}.zip
Source1:        FormEncode-doc-infrastructure.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  unzip
Provides:       python-formencode = %{version}
Obsoletes:      python-formencode < %{version}
# Documentation requirements:
BuildRequires:  python-Sphinx

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
FormEncode validates and converts nested structures. It allows for
a declarative form of defining the validation, and decoupled processes
for filling and generating forms.

%package doc
Summary:        HTML form validation, generation, and conversion package
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n FormEncode-%{version} -a1
find . -name \*.txt -exec sed -i 's/\r$//g' {} \;
sed -i 's/\r$//g' PKG-INFO README.rst

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# install documentation
rm -r %{buildroot}/%{python_sitelib}/docs # remove misplaced documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r README.rst build/sphinx/html %{buildroot}%{_docdir}/%{name}/

%fdupes %{buildroot}/%{_prefix}

%files
%defattr(-,root,root,-)
%exclude %{_docdir}/%{name}/html
%doc %dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/README.rst
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc %dir %{_docdir}/%{name}/html
%doc %{_docdir}/%{name}/html/*

%changelog
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 1.3.0:
  * Support validation of email addresses with unicode domain names
  * FormEncode 1.3 is no longer compatible with Python 2.3, 2.4, or
    2.5
  * FormEncode now also runs under Python 3.2 and 3.3
  * Validation of email addresses using resolve_domain option now
    requires the dnspython third party library instead of pyDNS
  * The FancyValidator methods _to_python, _from_python,
    validate_python and validate_other have been renamed to
    _convert_to_python, _convert_from_python, _validate_python and
    _validate_other, respectively
- add fdupes as BuildRequires and call it after install
- fix end of line of README.rst
- remove chmod of msgfmt.py: file deleted upstream
- install html documentation in the docdir of the main package
- do not install PKG-INFO in the documentation: already provided
  by the egg-info
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Aug  5 2013 hpj@urpla.net
- somebody updated this package to 1.2.6 (not me)
- added missing pieces in order to generate sphinx documentation
- create documentation in separate -doc package
- fix various wrong line endings
* Mon Jun 10 2013 dmueller@suse.com
- update to 1.2.5:
  * The method field_is_empty was added to
  formencode.validators.FormValidator
  * Fix packaging issue with i18n files (from Juliusz Gonera)
* Wed Mar 14 2012 saschpe@suse.de
- Set license to SDPX style (Python-2.0)
- Removed outdated %%clean section
- Simplified macro usage
- Only package HTML documentation (not the doc sources)
* Thu Sep  1 2011 saschpe@suse.de
- Add provides/obsoletes for python-formencode
* Thu Sep  1 2011 saschpe@suse.de
- Renamed to python-FormEncode to match upstream name
- Properly package documentation
* Sat Jun  6 2009 lars@linux-schulserver.de
- disable runtime dependency to python-setuptools
* Mon Apr 27 2009 lars@linux-schulserver.de
- update to 1.2.2
- remove FormEncode-1.2-svn-fixes.patch
- added rpmlintrc
* Sat Dec 13 2008 jfunk@funktronics.ca
- Apply some fixes from SVN
* Tue Dec  2 2008 jfunk@funktronics.ca
- Update to 1.2
  * Added :class:`formencode.validators.IPAddress`, validating IP
  addresses, from Leandro Lucarella.
  * Added :meth:`formencode.api.Invalid.__unicode__`
  * In :mod:`formencode.htmlfill` use a default encoding of utf8 when
  handling mixed ``str``/``unicode`` content.  Also do not modify
  ``<input type="image">`` tags (previously ``src`` would be
  overwritten, for no good reason).
  * In :class:`formencode.validators.Email` allow single-character
  domain names (like x.com).
  * Make :class:`formencode.validators.FieldsMatch` give a normal
  ``Invalid`` exception if you pass it a non-dictionary.  Also treat
  all missing keys as the empty string (previously the first key was
  required and would raise KeyError).
  * :class:`formencode.validators.Number` works with ``inf`` float
  values (before it would raise a OverflowError).
  * The ``tw`` locale has been renamed to the more standard ``zh_TW``.
  * Added Japanese and Turkish translations.
  * Fixed some outdated translations and errors in Spanish and Greek
  translations. Translations now managed with `Babel
  <http://babel.edgewall.org/>`_.
- 1.1
  * Fixed the ``is_empty()`` method in
  :class:`formencode.validators.FieldStorageUploadConverter`;
  previously it returned the opposite of the intended result.
  * Added a parameter to ``htmlfill.render()``: ``prefix_error``.  If
  this parameter is true (the default) then errors automatically go
  before the input field; if false then they go after the input field.
  * Remove deprecated modules: ``fields``, ``formgen``, ``htmlform``,
  ``sqlformgen``, and ``sqlschema``.
  * Added ``formencode.htmlrename``, which renames HTML inputs.
  * In ``formencode.htmlfill``, non-string values are compared usefully
  (e.g., a select box with integer values).
  * The validators ``Int`` and ``Number`` both take min/max arguments
  (from Shannon Behrens).
  * Validators based on ``formencode.validators.FormValidator`` will not
  treat ``{}`` as an empty (unvalidated) value.
  * Some adjustments to the URL validator.
  * :class:`formencode.compound.All` does not handle empty values,
  instead relying on sub-validators to check for emptiness.
  * Fixed the ``if_missing`` attribute in
  :class:`formencode.foreach.ForEach`; previously it would be the same
  list instance, so if you modified it then it would effect future
  ``if_missing`` values (reported by Felix Schwarz).
  * Added formatter to :mod:`formencode.htmlfill`, so you can use
  ``<form:error name="field_name" formatter="ignore" />`` -- this will
  cause the error to be swallowed, not shown to the user.
  * Added :class:`formencode.validators.XRI` for validation i-names,
  i-numbers, URLs, etc (as used in OpenID).
  * Look in ``/usr/share/locale`` for locale files, in addition to the
  normal locations.
  * Quiet Python 2.6 deprecation warnings.
  * Fix :class:`formencode.validators.URL`, which was accepting illegal
  characters (like newlines) and did not accept http://domain:PORT/
- 1.0.1
  * ``chained_validators`` were removed from Schema somehow; now
  replaced and working.
  * Put in missing ``htmlfill.render(error_class=...)`` parameter (was
  documented and implemented, but ``render()`` did not pass it
  through).
* Mon Nov 10 2008 cfarrell1980@gmail.com
- try building with --record-rpm instead of --record - 1.0-1
* Tue Mar 18 2008 jfunk@funktronics.ca
- Update to 1.0
* Wed Dec 26 2007 jfunk@funktronics.ca
- Fix bad python interpreter path
* Mon Dec 17 2007 jfunk@funktronics.ca
- Update to 0.9:
  - Backward incompatible changes
  * The notion of "empty" has changed to include empty lists,
  dictionaries, and tuples.  If you get one of these values passed
  into (or generated by) a validator with ``not_empty=True`` you can
  get exceptions where you didn't previously.
  - Enhancements
  * Added support for Paste's MultiDict dictionary as input to
  Schema.to_python, by converting it to a normal dict via MultiDict.mixed.
  Previously MultiDicts wouldn't work with CompoundValidators (like
  ForEach)
  * Added encoding parameter to htmlfill, which will handle cases when mixed
  str and unicode objects are used (turning all str objects into unicode)
  * Include ``formencode.validators.InternationalPhoneNumber`` from
  W-Mark Kubacki.
  * ``validators.Int`` takes ``min`` and ``max`` options (from Felix
  Schwarz).
  * You can control the missing message (which by default is just
  "Missing Value") using the message ``"missing"`` in a validator
  (also from James Gardner).
  * Added ``validators.CADR`` (for IP addresses with an optional range)
  and ``validators.MACAddress`` (from Christoph Haas).
  - Bug Fixes
  * Be friendlier when loaded from a zip file (as with py2exe);
  previously only egg zip files would work.
  * Fixed bug in htmlfill when a document ends with no trailing text
  after the last tag.
  * Fix problem with HTMLParser's default unescaping routing, which only
  understood a very limited number of entities in attribute values.
  * Fix problem with looking up A records for email addresses.
  * ``validators.String`` now always returns strings.  It also converts
  lists to comma-separated strings (no ``[...]``), and can encode
  unicode if an ``encoding`` parameter is given.  Empty values are
  handled better.
  * ``validators.UnicodeString`` properly handles non-Unicode inputs.
  * Make ``validators.DateConverter`` serialize dates properly
  (from James Gardner).
  * Minor fix to setup.py to make FormEncode more friendly with
  zc.buildout.
* Sun Apr 22 2007 jfunk@funktronics.ca
- Update to 0.7.1:
  From 0.7.1:
  * Set ``if_missing=()`` on ``validators.Set``, as a missing value
  usually means empty for this value.
  * Fix for ``Email`` validator that searches A records in addition to
  MX records (from Jacob Smullyan).
  * Fixes for the ``es`` locale.
  From 0.7:
  * **Backward compatibility issue**: Due to the addition of i18n
  (internationalization) to FormEncode, Invalid exceptions now have
  unicode messages.  You may encounter unicode-related errors if you
  are mixing these messages with non-ASCII ``str`` strings.
  * gettext-enabled branch merged in
  * Fixes `#1457145: Fails on URLs with port numbers
  <http://sourceforge.net/tracker/index.php?func=detail&aid=1457145&group_id=91231&atid=596416>`_
  * Fixes `#1559918 Schema fails to accept unicode errors
  <http://sourceforge.net/tracker/index.php?func=detail&aid=1559918&group_id=91231&atid=596416>`_
  * ``from formencode.validators import *`` will import the ``Invalid``
  exception now.
  * ``Invalid().unpack_errors(encode_variables=True)`` now filters out
  None values (which ``ForEach`` can produce even for keys with no
  errors).
* Sun Jan  7 2007 - poeml@suse.de
- update to 0.6
* Sun Jun 25 2006 jfunk@funktronics.ca
- Remove noarch
* Thu Jun 22 2006 jfunk@funktronics.ca
- No longer need pth kludge
* Wed Jun 21 2006 jfunk@funktronics.ca
- Update
* Wed Oct 12 2005 jfunk@funktronics.ca
- Initial release
